/*
 *  Copyright (C) 2006 Ludovic Jacomme (ludovic.jacomme@gmail.com)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>
#include <sys/time.h>
#include <fcntl.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <pspctrl.h>
#include <pspkernel.h>
#include <pspdebug.h>
#include <pspiofilemgr.h>

#include "global.h"
#include "psp_kbd.h"
#include "psp_gr.h"
#include "psp_pg.h"
#include "psp_battery.h"
#include "psp_menu.h"
#include "psp_menu_help.h"

  static int psp_menu_dirty = 1;

  static char* psp_menu_help[] =
  {
    "Square     Press Highlighted Key",
    "Triangle   Backspace",
    "Circle     Alpha",
    "Cross      Enter",
    "",
    "Up         Up",
    "Down       Down",
    "Left       Left",
    "Right      Right",
    "",
    "L          Shift L",
    "R          Shift R",
    "",
    "Start      On",
    "Select     Next",
    "",
    "Select+L   Emulator Menu",
    "Start+L    Help Menu",
    "Start+R    Swap Analog/Cursor Mode",
    "",
    "Analog     Highlight key on keyboard",
    NULL,
  };

static void 
psp_display_screen_help(void)
{
  int menu_id = 0;
  int x       = 0;
  int y       = 0;
  int y_step  = 0;

  if (psp_menu_dirty) {
    psp_draw_menu_background();
    psp_menu_dirty = 0;

    psp_pg_back_print( 30,10, " Start+L+R: EXIT ", PSP_MENU_WARNING_COLOR);

    psp_display_screen_menu_battery();

    psp_pg_back_print(30, 254, " Select: Back ", 
                      PSP_MENU_BORDER_COLOR);

    x      = 40;
    y      = 25;
    y_step = 10;
  
    menu_id = 0;
    while (psp_menu_help[menu_id]) {
      psp_pg_back_print(x, y, psp_menu_help[menu_id], PSP_MENU_TEXT_COLOR);
      y += y_step;
      menu_id++;
    }
  }
}

int 
psp_help_menu(int do_flip)
{
  SceCtrlData c;
  long        new_pad;
  long        old_pad;
  int         last_time;
  int         end_menu;

  psp_kbd_wait_no_button();

  if (do_flip) {
    psp_pg_flip();
  }

  old_pad   = 0;
  last_time = 0;
  end_menu  = 0;

  psp_menu_dirty = 1;

  while (! end_menu)
  {
    psp_display_screen_help();

    while (1)
    {
      sceCtrlReadBufferPositive(&c, 1);
      c.Buttons &= PSP_ALL_BUTTON_MASK;

      if (c.Buttons) break;
    }

    new_pad = c.Buttons;

    if ((old_pad != new_pad) || ((c.TimeStamp - last_time) > PSP_MENU_MIN_TIME)) {
      last_time = c.TimeStamp;
      old_pad = new_pad;

    } else continue;

    if ((c.Buttons & (PSP_CTRL_LTRIGGER|PSP_CTRL_RTRIGGER|PSP_CTRL_START)) ==
        (PSP_CTRL_LTRIGGER|PSP_CTRL_RTRIGGER|PSP_CTRL_START)) {
      /* Exit ! */
      psp_exit(0);
    } else
    if(new_pad & PSP_CTRL_SELECT) {
      /* Back to Main menu */
      end_menu = 1;
    }
  }
 
  psp_kbd_wait_no_button();

  if (do_flip) {
    psp_pg_clear_screen( PSP_MENU_BLACK_COLOR );
    psp_pg_flip();
  }

  return 1;
}

